@@ -164,14 +164,11 @@ class CodeReviewer:
                         file_name=review.get("file_name", "NA"),
                     )
                     markdown_output += ct + "\n"
+
         if high_ranked_issues > 0:
-            markdown_output = (
-                "❗ This review needs attention. 🚨\n\nHere are some feedback:\n\n"
-                + markdown_output
+            status_msg = (
+                "❗ **Attention Required:** This PR has potential issues. 🚨\n\n"
             )
         else:
-            markdown_output = (
-                "✅ This is a good review! 👍\n\nHere are some feedback:\n\n"
-                + markdown_output
-            )
-        return markdown_title + markdown_output
+            status_msg = "✅ **All Clear:** This PR is ready to merge! 👍\n\n"
+        return markdown_title + status_msg + markdown_output
